'use client';
var jsxRuntime = require('react/jsx-runtime');
require('@mui/material/Skeleton');
require('@mui/material/Typography');
var react = require('react');
var Backdrop = require('@mui/material/Backdrop');
var CircularProgress = require('@mui/material/CircularProgress');
var material = require('@mui/material');
var DecorativeTitleClient = require('./DecorativeTitle-client-7Fz8mPtP.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var Backdrop__default = /*#__PURE__*/_interopDefault(Backdrop);
var CircularProgress__default = /*#__PURE__*/_interopDefault(CircularProgress);

/**
 * 用來顯示載入中的內容，通常用在列表或表格中。
 *
 * 預設會顯示 3 個長條狀 Skeleton 元件。
 *
 * 參考 [Material-UI Skeleton](https://mui.com/material-ui/react-skeleton/)
 */ function LoadingContent({ count, height }) {
    return /*#__PURE__*/ jsxRuntime.jsx(material.Stack, {
        spacing: 2,
        component: "div",
        "aria-label": "loading content",
        children: Array(count || 3).fill(null).map((_, i)=>i).map((key)=>/*#__PURE__*/ jsxRuntime.jsx(material.Skeleton, {
                variant: "rounded",
                height: height || 40
            }, key))
    });
}

/**
 * `LoadingFullScreen` 全螢幕讀取中，通常用於非同步操作時提示使用者等待。
 *
 * 參考 [Material-UI Backdrop](https://mui.com/material-ui/react-backdrop/)
 */ function LoadingFullScreen({ sx, children = /*#__PURE__*/ jsxRuntime.jsx(CircularProgress__default.default, {}), ...rest }) {
    return /*#__PURE__*/ jsxRuntime.jsx(Backdrop__default.default, {
        sx: {
            zIndex: (theme)=>theme.zIndex.drawer + 1000,
            ...sx
        },
        ...rest,
        children: children
    });
}

const getCount = (count)=>{
    if (count < 3) {
        return 3;
    }
    if (count > 5) {
        return 5;
    }
    return count;
};
const bounceAnimation = (frequency, delay)=>({
        animation: `bounce-loading ${frequency}s ${delay * 0.07}s infinite ease-in-out`,
        animationFillMode: 'both',
        '@keyframes bounce-loading': {
            '33%': {
                transform: 'translateY(10px)'
            },
            '66%': {
                transform: 'translateY(-10px)'
            },
            '100%': {
                transform: 'translateY(0)'
            }
        }
    });
const pulseAnimation = (frequency, delay)=>({
        animation: `pulse-loading ${frequency}s ${delay * 0.12 / 1}s infinite cubic-bezier(0.2, 0.68, 0.18, 1.08)`,
        animationFillMode: 'both',
        '@keyframes pulse-loading': {
            '0%': {
                transform: 'scale(1)',
                opacity: 1
            },
            '50%': {
                transform: 'scale(0.1)',
                opacity: 0.7
            },
            '80%': {
                transform: 'scale(1)',
                opacity: 1
            }
        }
    });
const beatAnimation = (frequency, delay)=>({
        animation: `beat-loading ${frequency}s ${delay % 2 ? 0 : `${0.35 / 1}`}s infinite linear`,
        animationFillMode: 'both',
        '@keyframes beat-loading': {
            '50%': {
                transform: 'scale(0.75)',
                opacity: 0.2
            },
            '100%': {
                transform: 'scale(1)',
                opacity: 1
            }
        }
    });
/**
 * `LoadingIndicator` 是一個用來顯示載入中的元件。
 */ const LoadingIndicator = /*#__PURE__*/ react.forwardRef(({ type = 'bounce', frequency = 0.75, count = 3 }, ref)=>/*#__PURE__*/ jsxRuntime.jsx(material.Box, {
        ref: ref,
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
        "data-testid": "loading-indicator",
        children: Array.from({
            length: getCount(count)
        }).map((_, index)=>/*#__PURE__*/ jsxRuntime.jsx(material.Box, {
                sx: {
                    margin: '2px',
                    width: '12px',
                    height: '12px',
                    bgcolor: 'primary.main',
                    borderRadius: '50%',
                    ...type === 'bounce' && bounceAnimation(frequency, index),
                    ...type === 'pulse' && pulseAnimation(frequency, index),
                    ...type === 'beat' && beatAnimation(frequency, index)
                }
            }, index))
    }));
if (process.env.NODE_ENV !== 'production') {
    LoadingIndicator.displayName = 'GwLoadingIndicator';
}

const CardInner = ({ children, title, headerProps = {}, contentProps = {}, cardActions, loading = false, loadingOptions, ...rest }, ref)=>/*#__PURE__*/ jsxRuntime.jsxs(material.Card, {
        ref: ref,
        elevation: 0,
        ...rest,
        sx: {
            border: 1,
            borderRadius: 2,
            borderColor: 'divider',
            ...rest?.sx
        },
        children: [
            title && /*#__PURE__*/ jsxRuntime.jsx(material.CardHeader, {
                ...headerProps,
                title: /*#__PURE__*/ jsxRuntime.jsx(DecorativeTitleClient.DecorativeTitle, {
                    loading: loading,
                    children: title
                }),
                action: cardActions,
                sx: {
                    borderBottom: 1,
                    borderColor: 'divider',
                    p: 2,
                    gap: 1,
                    '& .MuiCardHeader-action': {
                        m: '0px auto',
                        alignSelf: 'center'
                    },
                    ...headerProps?.sx
                },
                titleTypographyProps: {
                    variant: 'subtitle1',
                    color: 'primary.main',
                    fontWeight: 'bold',
                    fontSize: '1.15rem',
                    ...headerProps?.titleTypographyProps
                }
            }),
            /*#__PURE__*/ jsxRuntime.jsx(material.CardContent, {
                ...contentProps,
                children: loading ? /*#__PURE__*/ jsxRuntime.jsx(LoadingContent, {
                    ...loadingOptions
                }) : children
            })
        ]
    });
/**
 * 表示一個卡片元件，用於展示相關的資訊。
 *
 * 參考 [Material-UI Card](https://mui.com/material-ui/react-card/)
 */ const Card = /*#__PURE__*/ react.forwardRef(CardInner);

exports.Card = Card;
exports.LoadingContent = LoadingContent;
exports.LoadingFullScreen = LoadingFullScreen;
exports.LoadingIndicator = LoadingIndicator;
