'use client';
var jsxRuntime = require('react/jsx-runtime');
var materialReactTable = require('material-react-table');

/**
 * `useTable` 是一個自定義的 Hook，用來設定 `Table` 的預設值。
 *
 * 參考 [Material React Table](https://www.material-react-table.com/docs/api/mrt-hooks#usematerialreacttable)
 */ const useTable = ({ enableSorting = false, enablePagination = false, bordered = false, displayColumnDefOptions = {}, ...rest })=>{
    const { 'mrt-row-select': mrtRowSelect = {}, ...displayColumnDefOptionsRest } = displayColumnDefOptions;
    const { muiTableBodyCellProps = {}, muiTableHeadCellProps = {}, ...mrtRowSelectRest } = mrtRowSelect;
    return materialReactTable.useMaterialReactTable({
        // localization: {
        //   of: '筆，總筆數:',
        //   rowsPerPage: '每頁數量',
        //   goToNextPage: '下一頁',
        //   goToPreviousPage: '上一頁',
        //   noRecordsToDisplay: '查無資料',
        // },
        // renderEmptyRowsFallback: ({ table }) => <span>Customized No Rows Overlay</span>,
        displayColumnDefOptions: {
            'mrt-row-select': {
                muiTableHeadCellProps: {
                    align: 'center',
                    ...muiTableHeadCellProps
                },
                muiTableBodyCellProps: {
                    align: 'center',
                    ...muiTableBodyCellProps
                },
                ...mrtRowSelectRest
            },
            ...displayColumnDefOptionsRest
        },
        muiTablePaperProps: {
            elevation: 0,
            sx: {
                backgroundColor: 'background.paper',
                borderRadius: 2,
                overflow: 'hidden',
                ...bordered && {
                    border: 1,
                    borderColor: 'divider'
                }
            }
        },
        muiTableHeadCellProps: {
            sx: {
                backgroundColor: 'primary.light',
                color: 'background.default'
            }
        },
        muiTableBodyRowProps: {
            sx: {
                backgroundColor: 'background.paper'
            }
        },
        muiTableBodyCellProps: {
            sx: {
                ...bordered && {
                    borderRight: 1,
                    borderColor: 'divider',
                    '&:last-child': {
                        borderRight: 0
                    }
                }
            }
        },
        muiBottomToolbarProps: {
            sx: {
                backgroundColor: 'background.paper',
                ...!enablePagination && {
                    minHeight: '2rem'
                },
                borderBottomLeftRadius: 2,
                borderBottomRightRadius: 2
            }
        },
        enableSorting,
        enablePagination,
        enableTopToolbar: false,
        enableColumnActions: false,
        enableDensityToggle: false,
        ...rest
    });
};
/**
 * `Table` 顧名思義就是一個表格元件，用來整齊的顯示行列數據。
 *
 * 參考 [Material React Table](https://www.material-react-table.com/)
 */ const Table = (tableProps)=>{
    const table = useTable(tableProps);
    return /*#__PURE__*/ jsxRuntime.jsx(materialReactTable.MaterialReactTable, {
        table: table
    });
};
if (process.env.NODE_ENV !== 'production') {
    Table.displayName = 'GwTable';
}

exports.Table = Table;
exports.useTable = useTable;
