'use client';
var jsxRuntime = require('react/jsx-runtime');
var react = require('react');
var Alert = require('@mui/material/Alert');
var Snackbar = require('@mui/material/Snackbar');
var toastStoreClient = require('./toastStore-client-Di8eSaMH.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var Alert__default = /*#__PURE__*/_interopDefault(Alert);
var Snackbar__default = /*#__PURE__*/_interopDefault(Snackbar);

/**
 * `Toaster` 用來顯示 Toast 訊息的容器元件，如要使用 `toast` 函式，請確保 `Toaster` 已經被掛載在應用程式的最上層。
 */ const Toaster = ({ defaultSnackbarProps = {}, defaultAlertProps })=>{
    const { open, key, message, type, toastProps = {}, alertProps = {} } = toastStoreClient.useToastStore();
    const { autoHideDuration = {
        success: 3000,
        warning: 3000,
        error: 5000,
        info: 3000
    }, anchorOrigin = {
        vertical: 'top',
        horizontal: 'center'
    } } = defaultSnackbarProps;
    const handleClose = (e, reason)=>{
        if (reason === 'clickaway' && type === 'error') return;
        toastStoreClient.setToasterState({
            open: false
        });
        toastProps.onClose?.(e, reason);
    };
    return /*#__PURE__*/ react.createElement(Snackbar__default.default, {
        ...defaultSnackbarProps,
        autoHideDuration: autoHideDuration[type],
        anchorOrigin: anchorOrigin,
        ...toastProps,
        open: open,
        onClose: handleClose,
        key: key
    }, /*#__PURE__*/ jsxRuntime.jsx(Alert__default.default, {
        ...defaultAlertProps,
        ...alertProps,
        severity: type,
        children: message
    }));
};
/**
 * `toast` 函式用來顯示 Toast 訊息。
 *
 * 提供四種訊息類型：`info`、`success`、`error`、`warning`，分別對應到四種不同的樣式。
 */ const toast = {
    info: (props)=>{
        toastStoreClient.setToasterState({
            ...props,
            key: new Date().valueOf(),
            open: true,
            type: 'info'
        });
    },
    success: (props)=>{
        toastStoreClient.setToasterState({
            ...props,
            key: new Date().valueOf(),
            open: true,
            type: 'success'
        });
    },
    error: (props)=>{
        toastStoreClient.setToasterState({
            ...props,
            key: new Date().valueOf(),
            open: true,
            type: 'error'
        });
    },
    warning: (props)=>{
        toastStoreClient.setToasterState({
            ...props,
            key: new Date().valueOf(),
            open: true,
            type: 'warning'
        });
    }
};

exports.Toaster = Toaster;
exports.toast = toast;
