'use client';
import { jsx } from 'react/jsx-runtime';
import { createElement } from 'react';
import Alert from '@mui/material/Alert';
import Snackbar from '@mui/material/Snackbar';
import { u as useToastStore, s as setToasterState } from './toastStore-client-BQ1mcu_C.mjs';

/**
 * `Toaster` 用來顯示 Toast 訊息的容器元件，如要使用 `toast` 函式，請確保 `Toaster` 已經被掛載在應用程式的最上層。
 */ const Toaster = ({ defaultSnackbarProps = {}, defaultAlertProps })=>{
    const { open, key, message, type, toastProps = {}, alertProps = {} } = useToastStore();
    const { autoHideDuration = {
        success: 3000,
        warning: 3000,
        error: 5000,
        info: 3000
    }, anchorOrigin = {
        vertical: 'top',
        horizontal: 'center'
    } } = defaultSnackbarProps;
    const handleClose = (e, reason)=>{
        if (reason === 'clickaway' && type === 'error') return;
        setToasterState({
            open: false
        });
        toastProps.onClose?.(e, reason);
    };
    return /*#__PURE__*/ createElement(Snackbar, {
        ...defaultSnackbarProps,
        autoHideDuration: autoHideDuration[type],
        anchorOrigin: anchorOrigin,
        ...toastProps,
        open: open,
        onClose: handleClose,
        key: key
    }, /*#__PURE__*/ jsx(Alert, {
        ...defaultAlertProps,
        ...alertProps,
        severity: type,
        children: message
    }));
};
/**
 * `toast` 函式用來顯示 Toast 訊息。
 *
 * 提供四種訊息類型：`info`、`success`、`error`、`warning`，分別對應到四種不同的樣式。
 */ const toast = {
    info: (props)=>{
        setToasterState({
            ...props,
            key: new Date().valueOf(),
            open: true,
            type: 'info'
        });
    },
    success: (props)=>{
        setToasterState({
            ...props,
            key: new Date().valueOf(),
            open: true,
            type: 'success'
        });
    },
    error: (props)=>{
        setToasterState({
            ...props,
            key: new Date().valueOf(),
            open: true,
            type: 'error'
        });
    },
    warning: (props)=>{
        setToasterState({
            ...props,
            key: new Date().valueOf(),
            open: true,
            type: 'warning'
        });
    }
};

export { Toaster as T, toast as t };
