'use client';
import { jsxs, jsx } from 'react/jsx-runtime';
import { Stack } from '@mui/material';
import { F as FileList, v as validateFileType } from './FileList-client-BrYa0uJ-.mjs';
import { U as UploadPanel } from './UploadPanel-client-Dsi8UWBe.mjs';
import { u as useFileUpload } from './useFileUpload-client-CCDiOt__.mjs';

const UploadFile = (props)=>{
    const { acceptMimeTypes = [], maxFiles = 1, files: outerFiles, onAddFile, onRemoveFile, onTypeError, i18n, ...rest } = props;
    const { files, addFile, removeFile } = useFileUpload({
        files: outerFiles,
        onAddFile,
        onRemoveFile
    });
    const handleAddFile = (e)=>{
        if (!e.target.files || e.target.files.length === 0) return;
        const targetFile = e.target.files[0];
        if (!validateFileType(targetFile, acceptMimeTypes)) {
            onTypeError?.();
            return;
        }
        addFile(targetFile);
    };
    const handleDropFile = (e)=>{
        if (!e.dataTransfer.files) return;
        const targetFile = e.dataTransfer.files[0];
        if (!validateFileType(targetFile, acceptMimeTypes)) {
            onTypeError?.();
            return;
        }
        addFile(targetFile);
    };
    return /*#__PURE__*/ jsxs(Stack, {
        spacing: 2,
        ...rest,
        children: [
            /*#__PURE__*/ jsx(UploadPanel, {
                acceptMimeTypes: acceptMimeTypes,
                handleAddFile: handleAddFile,
                handleDropFile: handleDropFile,
                disabled: maxFiles <= files.length,
                i18n: i18n
            }),
            /*#__PURE__*/ jsx(FileList, {
                files: files,
                handleDeleteFile: removeFile
            })
        ]
    });
};

export { UploadFile as U };
