'use client';
import { jsxs, jsx } from 'react/jsx-runtime';
import { CloudUploadOutlined } from '@mui/icons-material';
import { styled, Box, Typography } from '@mui/material';
import { useState } from 'react';
import { B as Button } from './Button-client-Diz1vWgB.mjs';
import '@mui/material/CircularProgress';
import '@mui/material/IconButton';

const VisuallyHiddenInput = styled('input')({
    clip: 'rect(0 0 0 0)',
    clipPath: 'inset(50%)',
    height: 1,
    overflow: 'hidden',
    position: 'absolute',
    bottom: 0,
    left: 0,
    whiteSpace: 'nowrap',
    width: 1
});
const UploadPanel = ({ acceptMimeTypes, handleAddFile, handleDropFile, disabled = false, i18n })=>{
    const [dragging, setDragging] = useState(false);
    const { main: mainText = ' Chose file or drag and drop here', sub: subText = '', button: buttonText = 'Chose file' } = i18n ?? {};
    return /*#__PURE__*/ jsxs(Box, {
        sx: {
            border: 1,
            borderStyle: 'dashed',
            borderRadius: 4,
            borderColor: dragging ? 'primary.main' : 'grey.400',
            width: '100%',
            p: 4,
            display: 'flex',
            flexDirection: 'column',
            alignItems: 'center',
            justifyContent: 'center',
            gap: 2
        },
        onDrop: (event)=>{
            event.preventDefault();
            setDragging(false);
            if (disabled) return;
            handleDropFile(event);
        },
        onDragEnter: (event)=>{
            event.preventDefault();
            setDragging(true);
        },
        onDragLeave: (event)=>{
            event.preventDefault();
            setDragging(false);
        },
        onDragOver: (event)=>{
            event.preventDefault();
            setDragging(true);
        },
        children: [
            /*#__PURE__*/ jsx(CloudUploadOutlined, {
                color: "primary",
                sx: {
                    width: 50,
                    height: 50
                }
            }),
            /*#__PURE__*/ jsxs(Box, {
                children: [
                    /*#__PURE__*/ jsx(Typography, {
                        sx: {
                            userSelect: 'none',
                            textAlign: 'center',
                            fontWeight: 'bold'
                        },
                        children: mainText
                    }),
                    subText && /*#__PURE__*/ jsx(Typography, {
                        sx: {
                            userSelect: 'none',
                            textAlign: 'center'
                        },
                        color: "text.secondary",
                        children: subText
                    })
                ]
            }),
            /*#__PURE__*/ jsxs(Button, {
                variant: "outlined",
                component: "label",
                disabled: disabled,
                children: [
                    buttonText,
                    /*#__PURE__*/ jsx(VisuallyHiddenInput, {
                        type: "file",
                        hidden: true,
                        onClick: (e)=>{
                            e.target.value = '';
                            e.stopPropagation();
                            if (disabled) {
                                e.preventDefault();
                            }
                        },
                        onChange: (e)=>{
                            if (disabled) return;
                            handleAddFile(e);
                        },
                        accept: acceptMimeTypes?.join(',')
                    })
                ]
            })
        ]
    });
};

export { UploadPanel as U };
